import React from 'react';
import PropTypes from 'prop-types';
import Input from 'reactstrap/lib/Input';
import FormFeedback from 'reactstrap/lib/FormFeedback';
import { FormattedMessage } from 'react-intl';

export function InputValidation({
  addValid, isValidCb, errorMessage, ...props
}) {
  const isValid = isValidCb();
  const isErrorMessageShown = addValid && !isValid;
  const addValidProp = addValid ? {
    valid: isValid,
    invalid: !isValid,
  } : {};

  return (
    <div className="text-right">
      <Input
        {...props}
        {...addValidProp}
      />
      {
        isErrorMessageShown &&
        <FormFeedback>
          <FormattedMessage id={errorMessage} />
        </FormFeedback>
      }
    </div>
  );
}

InputValidation.propTypes = {
  addValid: PropTypes.bool,
  isValidCb: PropTypes.func,
  errorMessage: PropTypes.string,
};

InputValidation.defaultProps = {
  addValid: true,
  isValidCb: () => false,
  errorMessage: '', // TODO: Add some key to react-intl for default error message
};
