import { chooseLocale, lang2LocaleMapping, locale2LangMapping, wrapRoute2Locale } from './localization';
import { LOCALE, LOCALE_KEYS, LANG_KEYS } from '../constants';

const store = {
  [LOCALE]: LOCALE_KEYS.RU_RU,
};

describe('localization', () => {
  describe('lang2LocaleMapping', () => {
    test('should get lang from locale mapping', () => {
      expect(lang2LocaleMapping[LANG_KEYS[LOCALE_KEYS.EN_US]]).toEqual(LOCALE_KEYS.EN_US);
      expect(lang2LocaleMapping[LANG_KEYS[LOCALE_KEYS.RU_RU]]).toEqual(LOCALE_KEYS.RU_RU);
    });
  });

  describe('locale2LangMapping', () => {
    test('should get locale from lang mapping', () => {
      expect(locale2LangMapping[LOCALE_KEYS.EN_US]).toEqual(LANG_KEYS[LOCALE_KEYS.EN_US]);
      expect(locale2LangMapping[LOCALE_KEYS.RU_RU]).toEqual(LANG_KEYS[LOCALE_KEYS.RU_RU]);
    });
  });

  describe('chooseLocale', () => {
    test('should chooseLocale from store', () => {
      expect(chooseLocale(store)).toEqual(LOCALE_KEYS.RU_RU);
    });

    test('should choose default locale', () => {
      expect(chooseLocale()).toEqual(LOCALE_KEYS.EN_US);
    });
  });

  describe('wrapRoute2Locale', () => {
    test('should add locale to route', () => {
      expect(wrapRoute2Locale('/test', LOCALE_KEYS.RU_RU)).toEqual(`/${LOCALE_KEYS.RU_RU}/test`);
    });
  });
});
